==> storagegateway-2.10.90-sources.jar: software/amazon/awssdk/services/storagegateway/paginators/DescribeTapesIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.storagegateway.paginators;

import java.util.Collections;
import java.util.Iterator;
import java.util.function.Function;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedItemsIterable;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.storagegateway.StorageGatewayClient;
import software.amazon.awssdk.services.storagegateway.model.DescribeTapesRequest;
import software.amazon.awssdk.services.storagegateway.model.DescribeTapesResponse;
import software.amazon.awssdk.services.storagegateway.model.Tape;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.storagegateway.StorageGatewayClient#describeTapesPaginator(software.amazon.awssdk.services.storagegateway.model.DescribeTapesRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.storagegateway.model.DescribeTapesResponse} that can be used to iterate
 * through all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.storagegateway.paginators.DescribeTapesIterable responses = client.describeTapesPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.storagegateway.paginators.DescribeTapesIterable responses = client
 *             .describeTapesPaginator(request);
 *     for (software.amazon.awssdk.services.storagegateway.model.DescribeTapesResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.storagegateway.paginators.DescribeTapesIterable responses = client.describeTapesPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #describeTapes(software.amazon.awssdk.services.storagegateway.model.DescribeTapesRequest)} operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class DescribeTapesIterable implements SdkIterable<DescribeTapesResponse> {
    private final StorageGatewayClient client;

    private final DescribeTapesRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public DescribeTapesIterable(StorageGatewayClient client, DescribeTapesRequest firstRequest) {
        this.client = client;
        this.firstRequest = firstRequest;
        this.nextPageFetcher = new DescribeTapesResponseFetcher();
    }

    @Override
    public Iterator<DescribeTapesResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    /**
     * Returns an iterable to iterate through the paginated {@link DescribeTapesResponse#tapes()} member. The returned
     * iterable is used to iterate through the results across all response pages and not a single page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<Tape> tapes() {
        Function<DescribeTapesResponse, Iterator<Tape>> getIterator = response -> {
            if (response != null && response.tapes() != null) {
                return response.tapes().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.<DescribeTapesResponse, Tape> builder().pagesIterable(this)
                .itemIteratorFunction(getIterator).build();
    }

    private class DescribeTapesResponseFetcher implements SyncPageFetcher<DescribeTapesResponse> {
        @Override
        public boolean hasNextPage(DescribeTapesResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.marker());
        }

        @Override
        public DescribeTapesResponse nextPage(DescribeTapesResponse previousPage) {
            if (previousPage == null) {
                return client.describeTapes(firstRequest);
            }
            return client.describeTapes(firstRequest.toBuilder().marker(previousPage.marker()).build());
        }
    }
}

==> storagegateway-2.17.102-sources.jar: software/amazon/awssdk/services/storagegateway/paginators/DescribeTapesIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.storagegateway.paginators;

import java.util.Collections;
import java.util.Iterator;
import java.util.function.Function;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedItemsIterable;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.storagegateway.StorageGatewayClient;
import software.amazon.awssdk.services.storagegateway.model.DescribeTapesRequest;
import software.amazon.awssdk.services.storagegateway.model.DescribeTapesResponse;
import software.amazon.awssdk.services.storagegateway.model.Tape;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.storagegateway.StorageGatewayClient#describeTapesPaginator(software.amazon.awssdk.services.storagegateway.model.DescribeTapesRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.storagegateway.model.DescribeTapesResponse} that can be used to iterate
 * through all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.storagegateway.paginators.DescribeTapesIterable responses = client.describeTapesPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.storagegateway.paginators.DescribeTapesIterable responses = client
 *             .describeTapesPaginator(request);
 *     for (software.amazon.awssdk.services.storagegateway.model.DescribeTapesResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.storagegateway.paginators.DescribeTapesIterable responses = client.describeTapesPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Please notice that the configuration of Limit won't limit the number of results you get with the paginator. It
 * only limits the number of results in each page.</b>
 * </p>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #describeTapes(software.amazon.awssdk.services.storagegateway.model.DescribeTapesRequest)} operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class DescribeTapesIterable implements SdkIterable<DescribeTapesResponse> {
    private final StorageGatewayClient client;

    private final DescribeTapesRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public DescribeTapesIterable(StorageGatewayClient client, DescribeTapesRequest firstRequest) {
        this.client = client;
        this.firstRequest = firstRequest;
        this.nextPageFetcher = new DescribeTapesResponseFetcher();
    }

    @Override
    public Iterator<DescribeTapesResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    /**
     * Returns an iterable to iterate through the paginated {@link DescribeTapesResponse#tapes()} member. The returned
     * iterable is used to iterate through the results across all response pages and not a single page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<Tape> tapes() {
        Function<DescribeTapesResponse, Iterator<Tape>> getIterator = response -> {
            if (response != null && response.tapes() != null) {
                return response.tapes().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.<DescribeTapesResponse, Tape> builder().pagesIterable(this)
                .itemIteratorFunction(getIterator).build();
    }

    private class DescribeTapesResponseFetcher implements SyncPageFetcher<DescribeTapesResponse> {
        @Override
        public boolean hasNextPage(DescribeTapesResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.marker());
        }

        @Override
        public DescribeTapesResponse nextPage(DescribeTapesResponse previousPage) {
            if (previousPage == null) {
                return client.describeTapes(firstRequest);
            }
            return client.describeTapes(firstRequest.toBuilder().marker(previousPage.marker()).build());
        }
    }
}
